@@ -26,26 +26,22 @@ def clear():
 	else:
 		system('cls')
 
-try:
-	f = open("client_secret.json", "r+")
-	f.write("{\"installed\":{\"client_id\":\"376353198664-o1v3m5ldtlaafq5rubfkmim13glspohr.apps.googleusercontent.com\",\"project_id\":\"gcoin-328514\",\"auth_uri\":\"https://accounts.google.com/o/oauth2/auth\",\"token_uri\":\"https://oauth2.googleapis.com/token\",\"auth_provider_x509_cert_url\":\"https://www.googleapis.com/oauth2/v1/certs\",\"client_secret\":\"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\",\"redirect_uris\":[\"urn:ietf:wg:oauth:2.0:oob\",\"http://localhost\"]}}")
-	f.flush()
-	gc = pygsheets.authorize()
-	f.close()
-except:
-	pass
+temp = ""
 
 def load_client_secret(path):
+	global temp
+	global gc2
 	f = open(path, "r+")
 	f.write("{\"installed\":{\"client_id\":\"376353198664-o1v3m5ldtlaafq5rubfkmim13glspohr.apps.googleusercontent.com\",\"project_id\":\"gcoin-328514\",\"auth_uri\":\"https://accounts.google.com/o/oauth2/auth\",\"token_uri\":\"https://oauth2.googleapis.com/token\",\"auth_provider_x509_cert_url\":\"https://www.googleapis.com/oauth2/v1/certs\",\"client_secret\":\"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\",\"redirect_uris\":[\"urn:ietf:wg:oauth:2.0:oob\",\"http://localhost\"]}}")
 	f.flush()
+	gc2 = pygsheets.authorize(path)
+	temp = path
+	f.close()
 	return 1
 
-gc = pygsheets.authorize()
-try:
-	f.close()
-except:
-	pass
+if temp == "":
+	temp = "client_secret.json"
+gc = gc2
 sh = gc.open("GCoin DB")
 wk1 = sh.sheet1
 
